<!--
  Familiar - Self-hosted AI Agent
  Copyright (c) 2026 George Scott Foley
  
  Licensed under the MIT License
  For commercial licensing, contact: licensing@familiar.ai
-->
{% if activity %}
<ul class="space-y-3">
    {% for log in activity %}
    <li class="flex items-start space-x-3 text-sm">
        <span class="flex-shrink-0 w-8 h-8 rounded-full bg-gray-100 flex items-center justify-center">
            {% if 'login' in log.action or 'session' in log.action %}
            🔐
            {% elif 'user' in log.action %}
            👤
            {% elif 'invite' in log.action %}
            ✉️
            {% elif 'message' in log.action %}
            💬
            {% else %}
            📋
            {% endif %}
        </span>
        <div class="flex-1 min-w-0">
            <p class="text-gray-800">
                <span class="font-medium">{{ log.action.replace('_', ' ').title() }}</span>
            </p>
            {% if log.details %}
            <p class="text-gray-500 truncate">{{ log.details }}</p>
            {% endif %}
            <p class="text-xs text-gray-400">{{ log.timestamp[:16].replace('T', ' ') }}</p>
        </div>
    </li>
    {% endfor %}
</ul>
{% else %}
<p class="text-gray-500 text-center py-4">No recent activity</p>
{% endif %}
