<!--
  Familiar - Self-hosted AI Agent
  Copyright (c) 2026 George Scott Foley
  
  Licensed under the MIT License
  For commercial licensing, contact: licensing@familiar.ai
-->
{% extends "base.html" %}

{% block title %}Check Your Email - Familiar Admin{% endblock %}

{% block content %}
<div class="min-h-[80vh] flex items-center justify-center">
    <div class="bg-white rounded-lg shadow-lg p-8 w-full max-w-md text-center">
        <div class="text-5xl mb-4">📧</div>
        <h1 class="text-2xl font-bold text-gray-800">Check Your Email</h1>
        <p class="text-gray-600 mt-4">
            We sent a login link to<br>
            <strong class="text-purple-600">{{ email }}</strong>
        </p>
        <p class="text-sm text-gray-500 mt-4">
            Click the link in the email to sign in. The link expires in 15 minutes.
        </p>
        
        <div class="mt-8">
            <a href="{{ url_for('admin.login') }}" class="text-purple-600 hover:text-purple-800">
                ← Back to login
            </a>
        </div>
    </div>
</div>
{% endblock %}
